;<?php exit; ?>
;
; Avactis configuration file
;

[DB]
DB_SERVER = "[[softdbhost]]"
DB_USER = "[[softdbuser]]"
DB_PASSWORD = "[[softdbpass]]"
DB_NAME = "[[softdb]]"
DB_TABLE_PREFIX = "[[dbprefix]]"
DB_PCONNECT = "false"

[SERVERINFO]
HTTP_URL = "[[softurl]]/"
COOKIEDOMAIN = "[[domhost]]"
COOKIEPATH = "/"
