<?php
/***********************************************************************
| Avactis (TM) Shopping Cart software developed by HBWSL.
| http://www.avactis.com
| -----------------------------------------------------------------------
| All source codes & content (c) Copyright 2004-2015, HBWSL.
| unless specifically noted otherwise.
| =============================================
| This source code is released under the Avactis License Agreement.
| The latest version of this license can be found here:
| http://www.avactis.com/license.php
|
| By using this software, you acknowledge having read this license agreement
| and agree to be bound thereby.
|
 ***********************************************************************/
?><?php
/***********************************************************************
| Avactis (TM) Shopping Cart software developed by HBWSL.
| http://www.avactis.com
| -----------------------------------------------------------------------
| All source codes & content (c) Copyright 2004-2010, HBWSL.
| unless specifically noted otherwise.
| =============================================
| This source code is released under the Avactis License Agreement.
| The latest version of this license can be found here:
| http://www.avactis.com/license.php
|
| By using this software, you acknowledge having read this license agreement
| and agree to be bound thereby.
|
 ***********************************************************************/
?><?php

define('PRODUCT_NAME', 'Avactis Shopping Cart');

define('PRODUCT_VERSION_NUMBER', '4.8.0');

define('PRODUCT_VERSION_DATE', 'Nov 28, 2016');

define('PRODUCT_VERSION_BUILD', '48000');

define('PRODUCT_VERSION_TYPE', 'AVACTIS-NEXT');

define('PRODUCT_VERSION_INTERNAL_TYPE', 'AVACTIS-NEXT');

define('PRODUCT_VERSION', PRODUCT_VERSION_NUMBER .'-'. PRODUCT_VERSION_TYPE);

define('PRODUCT_DISTRIBUTOR', 'Softaculous');

?>